@@ -37,14 +37,16 @@ class State(BaseModel):
     hvac_mode: EntityInfo
     hvac_mode2: EntityInfo
     target_temperature: EntityInfo
-    target_temperature_high: EntityInfo
-    target_temperature_low: EntityInfo
-    min_temp: EntityInfo
-    max_temp: EntityInfo
     hvac_action: EntityInfo
     current_temperature: EntityInfo
     room1_thermostat_mode: EntityInfo
-    outside_temperature: EntityInfo
+
+
+class StaticState(BaseModel):
+    """Class for entities that are not changing"""
+
+    min_temp: EntityInfo
+    max_temp: EntityInfo
 
 
 class Sensor(BaseModel):
@@ -70,7 +72,7 @@ class Device(BaseModel):
 
 
 class Info(BaseModel):
-    """Object holding the heatingsystem info.
+    """Object holding the heatingSystem info.
 
     Attributes:
         name: Name of the sub-device.
